==> ejc-bfyjerp-impl-3.0.0-20250124.081834-124-sources.jar: com/ejianc/business/oa/bean/InsurancePaymentSetEntity.java <==
package com.ejianc.business.oa.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 人力申请-保险缴纳申请基数设置
 * 
 * @author generator
 * 
 */
 @TableName("ejc_oa_insurance_payment_set")
public class InsurancePaymentSetEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="create_user_name")
    private String createUserName; // 创建人名称
    @TableField(value="modify_user_name")
    private String modifyUserName; // 修改人名称
    @TableField(value="insurance_payment_base_mny")
    private BigDecimal insurancePaymentBaseMny; // 保险缴纳基数
    @TableField(value="undertake_percent")
    private BigDecimal undertakePercent; // 费用承担比例
    @TableField(value="endownment_person_percent")
    private BigDecimal endownmentPersonPercent; // 养老保险个人比例
    @TableField(value="endownment_company_percent")
    private BigDecimal endownmentCompanyPercent; // 养老保险企业比例
    @TableField(value="unemployee_person_percent")
    private BigDecimal unemployeePersonPercent; // 失业保险个人比例
    @TableField(value="unemployee_company_percent")
    private BigDecimal unemployeeCompanyPercent; // 失业保险企业比例
    @TableField(value="injury_person_percent")
    private BigDecimal injuryPersonPercent; // 工伤保险个人比例
    @TableField(value="injury_company_percent")
    private BigDecimal injuryCompanyPercent; // 工伤保险企业比例
    @TableField(value="base_medical_person_percent")
    private BigDecimal baseMedicalPersonPercent; // 基本医疗保险个人比例
    @TableField(value="base_medical_company_percent")
    private BigDecimal baseMedicalCompanyPercent; // 基本医疗保险企业比例
    @TableField(value="serious_medical_company_percent")
    private BigDecimal seriousMedicalCompanyPercent; // 大病医疗保险企业比例
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="state")
    private Integer state; // 状态(0-停用,1-启用)


    public Integer getState() {
        return state;
    }

    public void setState(Integer state) {
        this.state = state;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getModifyUserName() {
        return modifyUserName;
    }

    public void setModifyUserName(String modifyUserName) {
        this.modifyUserName = modifyUserName;
    }
    public BigDecimal getInsurancePaymentBaseMny() {
        return insurancePaymentBaseMny;
    }

    public void setInsurancePaymentBaseMny(BigDecimal insurancePaymentBaseMny) {
        this.insurancePaymentBaseMny = insurancePaymentBaseMny;
    }
    public BigDecimal getUndertakePercent() {
        return undertakePercent;
    }

    public void setUndertakePercent(BigDecimal undertakePercent) {
        this.undertakePercent = undertakePercent;
    }
    public BigDecimal getEndownmentPersonPercent() {
        return endownmentPersonPercent;
    }

    public void setEndownmentPersonPercent(BigDecimal endownmentPersonPercent) {
        this.endownmentPersonPercent = endownmentPersonPercent;
    }
    public BigDecimal getEndownmentCompanyPercent() {
        return endownmentCompanyPercent;
    }

    public void setEndownmentCompanyPercent(BigDecimal endownmentCompanyPercent) {
        this.endownmentCompanyPercent = endownmentCompanyPercent;
    }
    public BigDecimal getUnemployeePersonPercent() {
        return unemployeePersonPercent;
    }

    public void setUnemployeePersonPercent(BigDecimal unemployeePersonPercent) {
        this.unemployeePersonPercent = unemployeePersonPercent;
    }
    public BigDecimal getUnemployeeCompanyPercent() {
        return unemployeeCompanyPercent;
    }

    public void setUnemployeeCompanyPercent(BigDecimal unemployeeCompanyPercent) {
        this.unemployeeCompanyPercent = unemployeeCompanyPercent;
    }
    public BigDecimal getInjuryPersonPercent() {
        return injuryPersonPercent;
    }

    public void setInjuryPersonPercent(BigDecimal injuryPersonPercent) {
        this.injuryPersonPercent = injuryPersonPercent;
    }
    public BigDecimal getInjuryCompanyPercent() {
        return injuryCompanyPercent;
    }

    public void setInjuryCompanyPercent(BigDecimal injuryCompanyPercent) {
        this.injuryCompanyPercent = injuryCompanyPercent;
    }
    public BigDecimal getBaseMedicalPersonPercent() {
        return baseMedicalPersonPercent;
    }

    public void setBaseMedicalPersonPercent(BigDecimal baseMedicalPersonPercent) {
        this.baseMedicalPersonPercent = baseMedicalPersonPercent;
    }
    public BigDecimal getBaseMedicalCompanyPercent() {
        return baseMedicalCompanyPercent;
    }

    public void setBaseMedicalCompanyPercent(BigDecimal baseMedicalCompanyPercent) {
        this.baseMedicalCompanyPercent = baseMedicalCompanyPercent;
    }
    public BigDecimal getSeriousMedicalCompanyPercent() {
        return seriousMedicalCompanyPercent;
    }

    public void setSeriousMedicalCompanyPercent(BigDecimal seriousMedicalCompanyPercent) {
        this.seriousMedicalCompanyPercent = seriousMedicalCompanyPercent;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    
}

==> ejc-bfyjerp-impl-3.0.0-20250620.023414-230-sources.jar: com/ejianc/business/oa/bean/InsurancePaymentSetEntity.java <==
package com.ejianc.business.oa.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 人力申请-保险缴纳申请基数设置
 * 
 * @author generator
 * 
 */
 @TableName("ejc_oa_insurance_payment_set")
public class InsurancePaymentSetEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="create_user_name")
    private String createUserName; // 创建人名称
    @TableField(value="modify_user_name")
    private String modifyUserName; // 修改人名称
    @TableField(value="insurance_payment_base_mny")
    private BigDecimal insurancePaymentBaseMny; // 保险缴纳基数
    @TableField(value="undertake_percent")
    private BigDecimal undertakePercent; // 费用承担比例
    @TableField(value="endownment_person_percent")
    private BigDecimal endownmentPersonPercent; // 养老保险个人比例
    @TableField(value="endownment_company_percent")
    private BigDecimal endownmentCompanyPercent; // 养老保险企业比例
    @TableField(value="unemployee_person_percent")
    private BigDecimal unemployeePersonPercent; // 失业保险个人比例
    @TableField(value="unemployee_company_percent")
    private BigDecimal unemployeeCompanyPercent; // 失业保险企业比例
    @TableField(value="injury_person_percent")
    private BigDecimal injuryPersonPercent; // 工伤保险个人比例
    @TableField(value="injury_company_percent")
    private BigDecimal injuryCompanyPercent; // 工伤保险企业比例
    @TableField(value="base_medical_person_percent")
    private BigDecimal baseMedicalPersonPercent; // 基本医疗保险个人比例
    @TableField(value="base_medical_company_percent")
    private BigDecimal baseMedicalCompanyPercent; // 基本医疗保险企业比例
    @TableField(value="serious_medical_company_percent")
    private BigDecimal seriousMedicalCompanyPercent; // 大病医疗保险企业比例
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="state")
    private Integer state; // 状态(0-停用,1-启用)
    @TableField("org_id")
    private Long orgId;
    @TableField("org_name")
    private String orgName;

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Integer getState() {
        return state;
    }

    public void setState(Integer state) {
        this.state = state;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getModifyUserName() {
        return modifyUserName;
    }

    public void setModifyUserName(String modifyUserName) {
        this.modifyUserName = modifyUserName;
    }
    public BigDecimal getInsurancePaymentBaseMny() {
        return insurancePaymentBaseMny;
    }

    public void setInsurancePaymentBaseMny(BigDecimal insurancePaymentBaseMny) {
        this.insurancePaymentBaseMny = insurancePaymentBaseMny;
    }
    public BigDecimal getUndertakePercent() {
        return undertakePercent;
    }

    public void setUndertakePercent(BigDecimal undertakePercent) {
        this.undertakePercent = undertakePercent;
    }
    public BigDecimal getEndownmentPersonPercent() {
        return endownmentPersonPercent;
    }

    public void setEndownmentPersonPercent(BigDecimal endownmentPersonPercent) {
        this.endownmentPersonPercent = endownmentPersonPercent;
    }
    public BigDecimal getEndownmentCompanyPercent() {
        return endownmentCompanyPercent;
    }

    public void setEndownmentCompanyPercent(BigDecimal endownmentCompanyPercent) {
        this.endownmentCompanyPercent = endownmentCompanyPercent;
    }
    public BigDecimal getUnemployeePersonPercent() {
        return unemployeePersonPercent;
    }

    public void setUnemployeePersonPercent(BigDecimal unemployeePersonPercent) {
        this.unemployeePersonPercent = unemployeePersonPercent;
    }
    public BigDecimal getUnemployeeCompanyPercent() {
        return unemployeeCompanyPercent;
    }

    public void setUnemployeeCompanyPercent(BigDecimal unemployeeCompanyPercent) {
        this.unemployeeCompanyPercent = unemployeeCompanyPercent;
    }
    public BigDecimal getInjuryPersonPercent() {
        return injuryPersonPercent;
    }

    public void setInjuryPersonPercent(BigDecimal injuryPersonPercent) {
        this.injuryPersonPercent = injuryPersonPercent;
    }
    public BigDecimal getInjuryCompanyPercent() {
        return injuryCompanyPercent;
    }

    public void setInjuryCompanyPercent(BigDecimal injuryCompanyPercent) {
        this.injuryCompanyPercent = injuryCompanyPercent;
    }
    public BigDecimal getBaseMedicalPersonPercent() {
        return baseMedicalPersonPercent;
    }

    public void setBaseMedicalPersonPercent(BigDecimal baseMedicalPersonPercent) {
        this.baseMedicalPersonPercent = baseMedicalPersonPercent;
    }
    public BigDecimal getBaseMedicalCompanyPercent() {
        return baseMedicalCompanyPercent;
    }

    public void setBaseMedicalCompanyPercent(BigDecimal baseMedicalCompanyPercent) {
        this.baseMedicalCompanyPercent = baseMedicalCompanyPercent;
    }
    public BigDecimal getSeriousMedicalCompanyPercent() {
        return seriousMedicalCompanyPercent;
    }

    public void setSeriousMedicalCompanyPercent(BigDecimal seriousMedicalCompanyPercent) {
        this.seriousMedicalCompanyPercent = seriousMedicalCompanyPercent;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    
}
